@@ -1,9 +1,7 @@
-__version__ = '0.3.0'
+__version__ = '0.4.0'
 __author__ = 'Oleg Kostromin, Marco Pasini, Iryna Kondrashchenko'
 
-from faulthandler import disable
-
 from falcon.main import initialize, AutoML
-from falcon.utils import disable_warnings
+from falcon.utils import disable_warnings, run_model
 
 disable_warnings()
\ No newline at end of file
